changeset 22250:a77d473867b8

*** empty log message ***
author Dan Nicolaescu <done@ece.arizona.edu>
date Tue, 26 May 1998 09:23:23 +0000
parents 9a8adf8f1efa
children 5989fa41cda6
files lisp/abbrev.el lisp/autoinsert.el lisp/autorevert.el lisp/complete.el lisp/completion.el lisp/dabbrev.el lisp/emulation/pc-select.el lisp/ffap.el lisp/filecache.el lisp/follow.el lisp/hippie-exp.el lisp/imenu.el lisp/iswitchb.el lisp/speedbar.el
diffstat 14 files changed, 38 insertions(+), 21 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/abbrev.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/abbrev.el	Tue May 26 09:23:23 1998 +0000
@@ -2,7 +2,7 @@
 
 ;; Copyright (C) 1985, 1986, 1987, 1992 Free Software Foundation, Inc.
 
-;; Keywords: abbrev
+;; Keywords: abbrev convenience
 
 ;; This file is part of GNU Emacs.
 
@@ -32,7 +32,8 @@
 This makes the commands that normally define mode-specific abbrevs
 define global abbrevs instead."
   :type 'boolean
-  :group 'abbrev-mode)
+  :group 'abbrev-mode
+  :group 'convenience)
 
 (defun abbrev-mode (arg)
   "Toggle abbrev mode.
--- a/lisp/autoinsert.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/autoinsert.el	Tue May 26 09:23:23 1998 +0000
@@ -4,6 +4,7 @@
 
 ;; Author: Charlie Martin <crm@cs.duke.edu>
 ;; Adapted-By: Daniel.Pfeiffer@Informatik.START.dbp.de, fax (+49 69) 7588-2389
+;; Keywords: convenience
 ;; Maintainer: FSF
 
 ;; This file is part of GNU Emacs.
@@ -52,7 +53,8 @@
 (defgroup auto-insert nil
   "Automatic mode-dependent insertion of text into new files."
   :prefix "auto-insert-"
-  :group 'files)
+  :group 'files
+  :group 'convenience)
 
 
 (defcustom auto-insert-mode nil
--- a/lisp/autorevert.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/autorevert.el	Tue May 26 09:23:23 1998 +0000
@@ -3,6 +3,7 @@
 ;; Copyright (C) 1997, 1998 Free Software Foundation, Inc.
 
 ;; Author: Anders Lindgren <andersl@csd.uu.se>
+;; Keywords: convenience
 ;; Created: 1 Jun 1997
 ;; Date: 3 Jul 1997
 
@@ -82,7 +83,8 @@
 
 Auto-Revert Mode can be activated for individual buffer.
 Global Auto-Revert Mode applies to all buffers."
-  :group 'files)
+  :group 'files
+  :group 'convenience)
 
 
 ;; Variables:
--- a/lisp/complete.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/complete.el	Tue May 26 09:23:23 1998 +0000
@@ -3,7 +3,7 @@
 ;; Copyright (C) 1990, 1991, 1992, 1993 Free Software Foundation, Inc.
 
 ;; Author: Dave Gillespie <daveg@synaptics.com>
-;; Keywords: abbrev
+;; Keywords: abbrev convenience
 ;; Version: 2.03
 ;; Special thanks to Hallvard Furuseth for his many ideas and contributions.
 
@@ -101,7 +101,8 @@
 (defgroup partial-completion nil
   "Partial Completion of items."
   :prefix "pc-"
-  :group 'minibuffer)
+  :group 'minibuffer
+  :group 'convenience)
 
 (defcustom partial-completion-mode nil
   "Toggle Partial Completion mode.
--- a/lisp/completion.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/completion.el	Tue May 26 09:23:23 1998 +0000
@@ -3,7 +3,7 @@
 ;; Copyright (C) 1990, 1993, 1995, 1997 Free Software Foundation, Inc.
 
 ;; Maintainer: FSF
-;; Keywords: abbrev
+;; Keywords: abbrev convenience
 ;; Author: Jim Salem <alem@bbnplanet.com> of Thinking Machines Inc.
 ;;  (ideas suggested by Brewster Kahle)
 
@@ -281,7 +281,8 @@
 
 (defgroup completion nil
   "Dynamic word-completion code."
-  :group 'matching)
+  :group 'matching
+  :group 'convenience)
 
 
 (defcustom enable-completion t
--- a/lisp/emulation/pc-select.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/emulation/pc-select.el	Tue May 26 09:23:23 1998 +0000
@@ -5,6 +5,7 @@
 ;; Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
 
 ;; Author: Michael Staats <michael@thp.Uni-Duisburg.DE>
+;; Keywords: convenience 
 ;; Created: 26 Sep 1995
 
 ;; This file is part of GNU Emacs.
@@ -80,7 +81,8 @@
 (defgroup pc-select nil
   "Emulate pc bindings."
   :prefix "pc-select"
-  :group 'editing-basics)
+  :group 'editing-basics
+  :group 'convenience)
 
 (defcustom pc-select-override-scroll-error t
   "*Non-nil means don't generate error on scrolling past edge of buffer.
--- a/lisp/filecache.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/filecache.el	Tue May 26 09:23:23 1998 +0000
@@ -2,7 +2,7 @@
 ;;
 ;; Author:  Peter Breton <pbreton@cs.umb.edu>
 ;; Created: Sun Nov 10 1996
-;; Keywords: 
+;; Keywords: convenience
 ;; Time-stamp: <1998-04-29 22:38:56 pbreton>
 ;;
 ;; Copyright (C) 1996 Free Software Foundation, Inc.
@@ -142,6 +142,7 @@
 (defgroup file-cache nil
   "Find files using a pre-loaded cache."
   :group 'files
+  :group 'convenience
   :prefix "file-cache-")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
--- a/lisp/hippie-exp.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/hippie-exp.el	Tue May 26 09:23:23 1998 +0000
@@ -5,7 +5,7 @@
 ;; Author: Anders Holst <aho@sans.kth.se>
 ;; Last change: 3 March 1998
 ;; Version: 1.6
-;; Keywords: abbrev
+;; Keywords: abbrev convenience
 
 ;; This file is part of GNU Emacs.
 
@@ -170,7 +170,8 @@
 
 (defgroup hippie-expand nil
   "Expand text trying various ways to find its expansion."
-  :group 'abbrev)
+  :group 'abbrev
+  :group 'convenience)
 
 (defvar he-num -1)
 
--- a/lisp/imenu.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/imenu.el	Tue May 26 09:23:23 1998 +0000
@@ -6,7 +6,7 @@
 ;;         Lars Lindberg <lli@sypro.cap.se>
 ;; Maintainer: FSF
 ;; Created: 8 Feb 1994
-;; Keywords: tools
+;; Keywords: tools convenience
 
 ;; This file is part of GNU Emacs.
 
@@ -73,6 +73,7 @@
   "Mode-specific buffer indexes."
   :group 'matching
   :group 'frames
+  :group 'convenience
   :link '(custom-manual "(elisp)Imenu"))
 
 (defcustom imenu-use-markers t
--- a/lisp/iswitchb.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/iswitchb.el	Tue May 26 09:23:23 1998 +0000
@@ -4,7 +4,7 @@
 
 ;; Author: Stephen Eglen <stephen@cns.ed.ac.uk>
 ;; Maintainer: Stephen Eglen <stephen@cns.ed.ac.uk>
-;; Keywords: extensions
+;; Keywords: extensions convenience
 ;; location: http://www.cns.ed.ac.uk/people/stephen/emacs/
 
 ;; This file is part of GNU Emacs.
@@ -213,6 +213,7 @@
 (defgroup iswitchb nil
   "Switch between buffers using substrings."
   :group 'extensions
+  :group 'convenience
   ;; These links are to be added in later versions of custom and
   ;; so are currently commented out.
   :link '(emacs-commentary-link :tag "Commentary" "iswitchb.el")
--- a/lisp/dabbrev.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/dabbrev.el	Tue May 26 09:23:23 1998 +0000
@@ -6,7 +6,7 @@
 ;; Maintainer: Lars Lindberg <Lars.Lindberg@sypro.cap.se>
 ;; Created: 16 Mars 1992
 ;; Lindberg's last update version: 5.7
 ;; Keywords: abbrev expand completion
 
 ;; This file is part of GNU Emacs.
 
@@ -101,7 +101,8 @@
 (defgroup dabbrev nil
   "Dynamic Abbreviations"
   :tag "Dynamic Abbreviations"
-  :group 'abbrev)
+  :group 'abbrev
+  :group 'convenience)
 
 (defcustom dabbrev-backward-only nil
   "*If non-nil, `dabbrev-expand' only looks backwards."
@@ -6,7 +6,7 @@
 ;; Created: 16 Mars 1992
 ;; Lindberg's last update version: 5.7
-;; Keywords: abbrev expand completion
+;; Keywords: abbrev expand completion convenience
 
 ;; This file is part of GNU Emacs.
--- a/lisp/ffap.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/ffap.el	Tue May 26 09:23:23 1998 +0000
@@ -4,7 +4,7 @@
 ;;
 ;; Author: Michelangelo Grigni <mic@mathcs.emory.edu>
 ;; Created: 29 Mar 1993
 ;; Keywords: files, hypermedia, matching, mouse
 ;; X-URL: ftp://ftp.mathcs.emory.edu/pub/mic/emacs/
 
 ;; This file is part of GNU Emacs.
@@ -105,7 +105,8 @@
 (defgroup ffap nil
   "Find file or URL at point."
   :link '(url-link :tag "URL" "ftp://ftp.mathcs.emory.edu/pub/mic/emacs/")
-  :group 'matching)
+  :group 'matching
+  :group 'convenience)
 
 ;; The code is organized in pages, separated by formfeed characters.
 ;; See the next two pages for standard customization ideas.
@@ -4,7 +4,7 @@
 ;; Author: Michelangelo Grigni <mic@mathcs.emory.edu>
 ;; Created: 29 Mar 1993
-;; Keywords: files, hypermedia, matching, mouse
+;; Keywords: files, hypermedia, matching, mouse, convenience
 ;; X-URL: ftp://ftp.mathcs.emory.edu/pub/mic/emacs/
 
--- a/lisp/follow.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/follow.el	Tue May 26 09:23:23 1998 +0000
@@ -6,7 +6,7 @@
 ;; Maintainer: Anders Lindgren <andersl@csd.uu.se>
 ;; Created: 25 May 1995
 ;; Version: 1.7
 ;; Keywords: display, window, minor-mode
 ;; Date: 4 Jun 1997
 
 ;; This file is part of GNU Emacs.
@@ -281,7 +281,8 @@
 (defgroup follow nil
   "Synchronize windows showing the same buffer."
   :prefix "follow-"
-  :group 'windows)
+  :group 'windows
+  :group 'convenience)
 
 (defvar follow-mode nil
   "Variable indicating if Follow mode is active.")
@@ -6,7 +6,7 @@
 ;; Created: 25 May 1995
 ;; Version: 1.7
-;; Keywords: display, window, minor-mode
+;; Keywords: display, window, minor-mode, convenience
 ;; Date: 4 Jun 1997
 
--- a/lisp/speedbar.el	Tue May 26 05:17:02 1998 +0000
+++ b/lisp/speedbar.el	Tue May 26 09:23:23 1998 +0000
@@ -4,7 +4,7 @@
 ;;
 ;; Author: Eric M. Ludlam <zappo@gnu.ai.mit.edu>
 ;; Version: 0.6.2
 ;; Keywords: file, tags, tools
 ;;
 ;; This file is part of GNU Emacs.
 ;;
@@ -346,6 +346,7 @@
   "File and tag browser frame."
   :group 'tags
   :group 'tools
+  :group 'convenience
   :version "20.3")
 
 (defgroup speedbar-faces nil
@@ -4,7 +4,7 @@
 ;; Author: Eric M. Ludlam <zappo@gnu.ai.mit.edu>
 ;; Version: 0.6.2
-;; Keywords: file, tags, tools
+;; Keywords: file, tags, tools, convenience
 ;;
 ;; This file is part of GNU Emacs.